# MD015 - No Missing Space After List Marker

This rule enforces that list markers must be followed by a space.

## Description

List items in Markdown should have a space after their marker for proper rendering and readability. This rule ensures that all list markers (`*`, `-`, `+`, or numbers) are followed by a space.

## Configuration

<!-- markdownlint-disable -->
- `require_space`: Whether to require a space after list markers (default: true)

<!-- markdownlint-enable -->

## Examples

<!-- markdownlint-disable -->
### Valid

```markdown
* Item 1
* Item 2
* Item 3

- First item
- Second item
- Third item

+ Alpha
+ Beta
+ Gamma

1. First
2. Second
3. Third
```

### Invalid

```markdown
*Item 1
*Item 2
*Item 3

-First item
-Second item
-Third item

+Alpha
+Beta
+Gamma

1.First
2.Second
3.Third
```

### Fixed

```markdown
* Item 1
* Item 2
* Item 3

- First item
- Second item
- Third item

+ Alpha
+ Beta
+ Gamma

1. First
<!-- markdownlint-enable -->
2. Second
3. Third
```

### Special Cases

- Applies to all list marker types (*, -, +, numbers)
- Ignores list markers in code blocks
- Handles nested lists with proper indentation
- Considers list continuations and multi-line list items
- Preserves indentation when fixing

## Related Rules

- MD004: Unordered list style
- MD007: Unordered list indentation
- MD029: Ordered list item prefix
- MD030: Spaces after list markers
