# MD016 - No Multiple Spaces After List Marker

## Description

This rule ensures that there is only one space after list markers in unordered and ordered lists.  
Multiple spaces after list markers can cause inconsistent rendering and make the document harder to read.

## Configuration

- `allow*multiple*spaces`: Whether to allow multiple spaces after list markers (default: false)

## Examples

<!-- markdownlint-disable -->
### Valid

```markdown
* Item 1
* Item 2
  * Nested item
  * Another nested item
* Item 3

1. First item
2. Second item
   1. Nested item
   2. Another nested item
3. Third item
```

### Invalid

```markdown
*  Item 1 (two spaces after marker)
*   Item 2 (three spaces after marker)
  *    Nested item (four spaces after marker)
  *     Another nested item (five spaces after marker)
*      Item 3 (six spaces after marker)

1.  First item (two spaces after marker)
2.   Second item (three spaces after marker)
   1.    Nested item (four spaces after marker)
   2.     Another nested item (five spaces after marker)
3.      Third item (six spaces after marker)
```

### Fixed

```markdown
* Item 1
* Item 2
  * Nested item
  * Another nested item
* Item 3

1. First item
2. Second item
   1. Nested item
   2. Another nested item
3. Third item
```
<!-- markdownlint-enable -->

## Special Cases

- This rule applies to both unordered lists (*, -, +) and ordered lists (1., 2., etc.)
- Nested list items should still be properly indented
- When `allow*multiple*spaces` is true, this rule will not flag multiple spaces after list markers

## Related Rules

- [MD004 - Unordered list style](md004.md): Ensures consistent use of list marker style
- [MD005 - List indentation](md005.md): Ensures consistent indentation for list items at the same level
- [MD007 - Unordered list indentation](md007.md): Verifies that nested list items are indented by a certain number of spaces
