# MD017 - No Emphasis as Heading

## Description

This rule prevents the use of emphasis (italic or bold) as a substitute for proper headings.  
Using emphasis to create headings can lead to inconsistent document structure and accessibility issues.

## Configuration

- `allow*emphasis*headings`: Whether to allow emphasis as headings (default: false)

## Examples

<!-- markdownlint-disable -->
### Valid

```markdown
# Proper Heading 1
## Proper Heading 2
### Proper Heading 3

This is a paragraph with *italic* and **bold** text.
```

### Invalid

```markdown
*This is not a proper heading*

**This is not a proper heading either**

***This is definitely not a proper heading***
```

### Fixed

```markdown
# This is not a proper heading

## This is not a proper heading either

### This is definitely not a proper heading
```
<!-- markdownlint-enable -->

## Special Cases

- This rule only flags emphasis that appears alone on a line
- Emphasis within other content is not affected
- Both single emphasis (*italic*) and double emphasis (**bold**) are checked
- Triple emphasis (***bold italic***) is also checked

## Related Rules

- [MD001 - Heading increment](md001.md): Ensures heading levels increment by one level at a time
- [MD003 - Heading style](md003.md): Ensures consistent heading style
- [MD018 - No missing space in ATX heading](md018.md): Ensures proper spacing in headings
