# MD030 - Spaces After List Markers

## Description

This rule ensures that there is a consistent number of spaces between list markers and the list content.  
By default, ordered lists should have one space after the list marker, and unordered lists should have  
one space after the list marker.

Consistent spacing improves readability and ensures proper rendering across different Markdown processors.

<!-- markdownlint-disable -->
## Examples

### Valid

```markdown
* Unordered list item with one space
* Another item

1. Ordered list item with one space
2. Another item
```

### Invalid

```markdown
*  Unordered list item with two spaces
*   Another item with three spaces

1.  Ordered list item with two spaces
2.   Another item with three spaces
```

### Fixed

```markdown
* Unordered list item with one space
* Another item with one space

1. Ordered list item with one space
2. Another item with one space
```
<!-- markdownlint-enable -->

## Configuration

This rule has the following configuration options:

- `ul_single`: Number of spaces after the list marker for single-line unordered list items. Default is `1`.
- `ol_single`: Number of spaces after the list marker for single-line ordered list items. Default is `1`.
- `ul_multi`: Number of spaces after the list marker for multi-line unordered list items. Default is `1`.
- `ol_multi`: Number of spaces after the list marker for multi-line ordered list items. Default is `1`.

## Special Cases

- This rule applies to both ordered and unordered lists
- It distinguishes between single-line and multi-line list items
- The rule checks the number of spaces immediately after the list marker
- It does not affect indentation of nested list items

## Related Rules

- [MD004 - Unordered list style](md004.md): Ensures consistent unordered list markers
- [MD005 - Consistent list indentation](md005.md): Ensures proper list indentation
- [MD007 - List indentation](md007.md): Checks for proper indentation of list items
