# MD034 - No Bare URLs

## Description

This rule ensures that URLs are not used as bare URLs in Markdown content. URLs should be enclosed in angle brackets (`<` and `>`) or formatted as proper Markdown links.

Bare URLs may not be properly recognized as clickable links in all Markdown renderers.

<!-- markdownlint-disable -->
## Examples

### Valid

```markdown
For more information, see <https://example.com>.

Visit [Example Website](https://example.com) for more details.

The URL is: <https://example.com/path/to/page.html?query=string#fragment>
```

### Invalid

```markdown
For more information, see https://example.com.

The URL is: https://example.com/path/to/page.html?query=string#fragment
```

### Fixed

```markdown
For more information, see <https://example.com>.

The URL is: <https://example.com/path/to/page.html?query=string#fragment>
```
<!-- markdownlint-enable -->

## Special Cases

- This rule does not apply to URLs within code blocks or code spans
- It does not affect URLs that are already properly formatted as Markdown links
- The rule checks for common URL protocols (http, https, ftp, etc.)
- URLs in HTML comments are ignored

## Related Rules

- [MD039 - No space inside link text](md039.md): Ensures proper formatting of link text
- [MD042 - No empty links](md042.md): Ensures links have content
- [MD051 - Link fragments should be valid](md051.md): Ensures link fragments point to valid headings
