# MD050 - Strong Emphasis Style

## Description

This rule ensures that strong emphasis markers (bold) use a consistent style throughout a document.  
Markdown supports two styles of strong emphasis markers: double asterisks (`**`) and double underscores (`__`).

By default, this rule enforces the use of double asterisks for strong emphasis.

<!-- markdownlint-disable -->
## Examples

### Valid

Consistent use of asterisks (when style is set to "asterisk"):

```markdown
This text has **bold** formatting.

This is another **strongly emphasized** text.
```

### Invalid

Mixed strong emphasis styles:

```markdown
This text has **bold** formatting.

This is another __strongly emphasized__ text.
```

### Fixed

```markdown
This text has **bold** formatting.

This is another **strongly emphasized** text.
```
<!-- markdownlint-enable -->

## Configuration

This rule has the following configuration options:

- `style`: The style of strong emphasis markers to enforce. Can be one of:
  - `"consistent"`: Enforce the first strong emphasis style used in the document (default)
  - `"asterisk"`: Enforce the use of double asterisks (`**`)
  - `"underscore"`: Enforce the use of double underscores (`__`)

## Special Cases

- This rule only applies to strong emphasis (bold)
- It does not apply to regular emphasis (italics)
- When style is set to "consistent", the first strong emphasis style used in the document is enforced
- The rule checks both the opening and closing strong emphasis markers
- The rule does not apply to code spans or code blocks

## Related Rules

- [MD049 - Emphasis style](md049.md): Similar rule for emphasis (italics)
- [MD036 - No emphasis as heading](md036.md): Prevents using emphasis instead of proper headings
- [MD037 - No spaces inside emphasis markers](md037.md): Ensures proper formatting of emphasis
